Tomography widgets
==================

Used for displaying or processing results [G1]_. 

.. [G1] J. Svoboda, et al. "Comparative analysis and new post-processing methods for plasma tomography at tokamaks." Journal of Instrumentation 14.11 (2019): C11001.

Displaying
----------
A basic window capable of displaying a single reconstruction DiagGraphWindow. Can load a sequence of reconstructions and be synchronized with other windows.  

Processing
----------

.. automodule:: tomotok.gui.roi
    :members: GraphRectangles, GraphContours
    :undoc-members:
    :show-inheritance:
    :noindex:


.. automodule:: tomotok.gui.profiler
    :members: GraphProfiler
    :show-inheritance:
    :noindex:


.. automodule:: tomotok.gui.merfer
    :members: GraphMerfer
    :show-inheritance:
    :noindex:
